@@ -26,19 +26,33 @@ function config_exists() {
         if [ -f "/etc/sysconfig/network-scripts/ifcfg-$interface" ]; then
             return 0
         fi
+    # Gentoo: return the value of grep -q INTERFACE in the config file, if it exists
+    elif [[ -a /etc/gentoo-release ]]; then
+        if [[ -a /etc/conf.d/net ]]; then
+            # the '=' is needed so eth0 doesn't match on eth0.1
+            grep -q "${interface}=" /etc/conf.d/net* || return 1
+        else
+            return 1
+        fi
     else
-        ifquery $interface >/dev/null 2>&1 && return 0 || return 1
+        ifquery "${interface}" >/dev/null 2>&1 && return 0 || return 1
     fi
     return 1
 }
 
 
 # Test to see if config-drive exists. If not, skip and assume DHCP networking
-# will work becasue sanity
+# will work because sanity
 if blkid -t LABEL="config-2" ; then
     # Mount config drive
     mkdir -p /mnt/config
-    mount -o mode=0700 $(blkid -t LABEL="config-2" | cut -d ':' -f 1) /mnt/config || true
+    BLOCKDEV="$(blkid -L config-2)"
+    TYPE="$(blkid ${BLOCKDEV} -o udev | grep FS_TYPE | cut -d '=' -f 2)"
+    if [[ "${TYPE}" == 'vfat' ]]; then
+        mount -o umask=0077 "${BLOCKDEV}" /mnt/config || true
+    else
+        mount -o mode=0700 "${BLOCKDEV}" /mnt/config || true
+    fi
     glean --ssh --skip-network --hostname
 fi
 
@@ -47,7 +61,7 @@ if [ -f /usr/bin/dpkg ] ; then
 fi
 
 if [ -n "$INTERFACE" ]; then
-    glean --interface $INTERFACE
+    glean --interface "${INTERFACE}"
 else
     glean
 fi
